pub fn challenge<E: Curve, D: Digest>(
shared_state: &impl Digestable,
data: Data<'_, E>,
commitment: &Commitment<E>,
) -> Challenge<E>Expand description
Deterministically compute challenge based on prior known values in protocol
pub fn challenge<E: Curve, D: Digest>(
shared_state: &impl Digestable,
data: Data<'_, E>,
commitment: &Commitment<E>,
) -> Challenge<E>Deterministically compute challenge based on prior known values in protocol